@@ -291,47 +291,3 @@ class Call(object):
                 return await fut
 
             return attr_fut
-async def basic_connect_example():
-    rumor = Rumor()
-    await rumor.start(cmd='cd ../rumor && go run .')  # Hook it up to your own local version of Rumor, if you like.
-
-    alice = rumor.actor('alice')
-    await alice.host.start().ok
-    # Flags are keyword arguments
-    await alice.host.listen(tcp=9000).ok
-    print("started alice")
-
-    bob = rumor.actor('bob')
-    await bob.host.start().ok
-    await bob.host.listen(tcp=9001).ok
-    print("started bob")
-
-    # Getting a result should be as easy as calling, and waiting for the key we are after
-    bob_addr = await bob.host.view().enr()
-    print('BOB has ENR: ', bob_addr)
-
-    # Print all ENR contents
-    await rumor.enr.view(bob_addr).ok
-
-    # Command arguments are just call arguments
-    await alice.peer.connect(bob_addr).ok
-    print("connected alice to bob!")
-
-    # When there are multiple entries containing some specific key,
-    #  you can also prefix with `listen_` to get each of the values:
-    async for msg in bob.peer.list().listen_msg():
-        print(f'bob peer list: {msg}')
-
-    async for msg in alice.peer.list().listen_msg():
-        print(f'alice peer list: {msg}')
-
-    # Or alternatively, collect all result data from the call:
-    bob_addr_data = await rumor.enr.view(bob_addr).ok
-    print("--- BOB host view data: ---")
-    print("\n".join(f"{k}: {v}" for k, v in bob_addr_data.items()))
-
-    # Close the Rumor process
-    await rumor.stop()
-
-
-asyncio.run(basic_connect_example())
